Enum cranelift_wasm::GlobalInit [−][src]
pub enum GlobalInit {
I32Const(i32),
I64Const(i64),
F32Const(u32),
F64Const(u64),
V128Const(V128Imm),
GetGlobal(GlobalIndex),
RefNullConst,
RefFunc(FuncIndex),
Import,
}Expand description
Globals are initialized via the const operators or by referring to another import.
Variants
An i32.const.
Tuple Fields of I32Const
0: i32An i64.const.
Tuple Fields of I64Const
0: i64An f32.const.
Tuple Fields of F32Const
0: u32An f64.const.
Tuple Fields of F64Const
0: u64A vconst.
Tuple Fields of V128Const
0: V128ImmA global.get of another global.
Tuple Fields of GetGlobal
0: GlobalIndexA ref.null.
A ref.func <index>.
Tuple Fields of RefFunc
0: FuncIndex< The global is imported from, and thus initialized by, a different module.