Enum cranelift_wasm::WasmError [−][src]
pub enum WasmError {
InvalidWebAssembly {
message: String,
offset: usize,
},
Unsupported(String),
ImplLimitExceeded,
User(String),
}Expand description
A WebAssembly translation error.
When a WebAssembly function can’t be translated, one of these error codes will be returned to describe the failure.
Variants
The input WebAssembly code is invalid.
This error code is used by a WebAssembly translator when it encounters invalid WebAssembly code. This should never happen for validated WebAssembly code.
Fields of InvalidWebAssembly
A feature used by the WebAssembly code is not supported by the embedding environment.
Embedding environments may have their own limitations and feature restrictions.
Tuple Fields of Unsupported
0: StringAn implementation limit was exceeded.
Cranelift can compile very large and complicated functions, but the implementation has limits that cause compilation to fail when they are exceeded.
Any user-defined error.
Tuple Fields of User
0: StringTrait Implementations
Convert from a BinaryReaderError to a WasmError.