Enum cranelift_wasm::EntityType [−][src]
pub enum EntityType {
Global(Global),
Memory(Memory),
Event(Event),
Table(Table),
Function(SignatureIndex),
Instance(InstanceTypeIndex),
Module(ModuleTypeIndex),
}Expand description
A type of an item in a wasm module where an item is typically something that can be exported.
Variants
A global variable with the specified content type
Tuple Fields of Global
0: GlobalA linear memory with the specified limits
Tuple Fields of Memory
0: MemoryAn event definition.
Tuple Fields of Event
0: EventA table with the specified element type and limits
Tuple Fields of Table
0: TableA function type where the index points to the type section and records a function signature.
Tuple Fields of Function
An instance where the index points to the type section and records a instance’s exports.
Tuple Fields of Instance
A module where the index points to the type section and records a module’s imports and exports.
Tuple Fields of Module