[−][src]Enum cranelift_wasm::EntityType
A type of an item in a wasm module where an item is typically something that can be exported.
Variants
Global(Global)A global variable with the specified content type
Memory(Memory)A linear memory with the specified limits
Event(Event)An event definition.
Table(Table)A table with the specified element type and limits
Function(SignatureIndex)A function type where the index points to the type section and records a function signature.
Instance(InstanceTypeIndex)An instance where the index points to the type section and records a instance's exports.
Module(ModuleTypeIndex)A module where the index points to the type section and records a module's imports and exports.