Enum cranelift_wasm::GlobalInit [−][src]
pub enum GlobalInit {
I32Const(i32),
I64Const(i64),
F32Const(u32),
F64Const(u64),
V128Const(V128Imm),
GetGlobal(GlobalIndex),
RefNullConst,
RefFunc(FuncIndex),
Import,
}Expand description
Globals are initialized via the const operators or by referring to another import.
Variants
I32Const(i32)An i32.const.
I64Const(i64)An i64.const.
F32Const(u32)An f32.const.
F64Const(u64)An f64.const.
V128Const(V128Imm)A vconst.
GetGlobal(GlobalIndex)A global.get of another global.
A ref.null.
RefFunc(FuncIndex)A ref.func <index>.
< The global is imported from, and thus initialized by, a different module.